@@ -82,11 +82,13 @@ class PkgManager(ABC):
     def build(
         self,
         package: Package,
+        skip_deps: Optional[List[str]] = None,
     ):
         """Build the package. If it has been built before during PBT running, we may skip the build step (i.e., caching results).
 
         Args:
             package: The package to build
+            skip_deps: The optional list of dependencies to skip
         """
         raise NotImplementedError()
 
@@ -175,7 +177,10 @@ class PkgManager(ABC):
             dir_paths.append(depfile)
 
         if len(patterns) > 0:
-            raise NotImplementedError()
+            for pattern in patterns:
+                if not (pattern.endswith("/**/*") and pattern[:-5].find("*") == -1):
+                    raise NotImplementedError()
+                dir_paths.append(pattern[:-5])
 
         output = []
         for file in files:
